@@ -1,4 +1,6 @@
 #!/usr/bin/python3
+# SPDX-FileCopyrightText: Peter Pentchev <roam@ringlet.net>
+# SPDX-License-Identifier: BSD-2-Clause
 """Run the feature-check test suite with several Python interpreters."""
 
 from __future__ import annotations
@@ -6,7 +8,7 @@ from __future__ import annotations
 import os
 import pathlib
 import re
-import subprocess
+import subprocess  # noqa: S404
 import sys
 import typing
 
@@ -29,8 +31,8 @@ def find_interpreters() -> list[pathlib.Path]:
     if missing:
         sys.exit(
             "Missing/invalid Python interpreters: {missing}".format(
-                missing=" ".join(map(str, missing))
-            )
+                missing=" ".join(map(str, missing)),
+            ),
         )
 
     return paths
